from hypothesis.strategies import SearchStrategy
from hypothesis.strategies import just

from dycw_utilities.tempfile import TemporaryDirectory


def temp_dirs() -> SearchStrategy[TemporaryDirectory]:
    return just(TemporaryDirectory())



from typing import Any


def ensure_str(x: Any, /) -> str:
    """Ensure an object is a string."""

    if isinstance(x, str):
        return x
    else:
        raise TypeError(f"{x} is not a string")



from collections.abc import Callable
from typing import Any
from typing import TypeVar


try:
    from typeguard import typeguard_ignore as _typeguard_ignore
except ModuleNotFoundError:  # pragma: no cover

    _T = TypeVar("_T", bound=Callable[..., Any])

    def typeguard_ignore(x: _T, /) -> _T:
        return x

else:
    typeguard_ignore = _typeguard_ignore  # type: ignore
